@@ -8,7 +8,7 @@ from tornado import gen
 from .cortx_authenticator import CortxAuthenticator
 # from .utils import (MultiPartUploadHelper,_get_key,_get_path, _get_full_path,_get_type,_get_format,_get_type_from_key)
 from .utils import (
-    _run_sync,MultiPartUploadHelper,_check_directory_exists,_check_file_exists,_get_model,_save_model,_delete_notebook,_rename_notebook,_new_untitled_notebook,_get_new_notebook,_copy_notebook,_create_new_checkpoint,_restore_notebook_checkpoint,_list_all_checkpoints,_delete__notebook_checkpoint
+    _run_sync,MultiPartUploadHelper,_check_directory_exists,_check_file_exists,_get_model,_save_model,_delete_notebook,_rename_notebook,_new_untitled_notebook,_get_new_notebook,_copy_notebook,_create_new_checkpoint,_restore_notebook_checkpoint,_list_all_checkpoints,_delete_notebook_checkpoint
     )
 from .utils import *
 import json 
@@ -61,7 +61,8 @@ class CortxJupyter(ContentsManager):
 
         @gen.coroutine
         def dir_exists_async():
-            return (yield _check_directory_exists(self._config(), path))
+            c = yield self._config()
+            return (yield _check_directory_exists(c, path))
 
         return _run_sync(dir_exists_async)
 
@@ -69,7 +70,8 @@ class CortxJupyter(ContentsManager):
 
         @gen.coroutine
         def file_exists_async():
-            return (yield _check_file_exists(self._config(), path))
+            c = yield self._config()
+            return (yield _check_file_exists(c, path))
 
         return _run_sync(file_exists_async)
 
@@ -78,61 +80,85 @@ class CortxJupyter(ContentsManager):
         print(path,content,type,format)
         @gen.coroutine
         def get_async():
-            return (yield _get_model(self._config(), path, content, type, format))
+            c = yield self._config()
+            return (yield _get_model(c, path, content, type, format))
 
         return _run_sync(get_async)
 
     @gen.coroutine
     def save(self, model, path):
         with (yield self.write_lock.acquire()):
-            return (yield _save_model(self._config(), model, path))
+            c = yield self._config()
+            return (yield _save_model(c, model, path))
 
     @gen.coroutine
     def delete(self, path):
         with (yield self.write_lock.acquire()):
-            yield _delete_notebook(self._config(), path)
+            c = yield self._config()
+            yield _delete_notebook(c, path)
 
     @gen.coroutine
     def update(self, model, path):
         with (yield self.write_lock.acquire()):
-            return (yield _rename_notebook(self._config(), path, model['path']))
+            c = yield self._config()
+            return (yield _rename_notebook(c, path, model['path']))
 
     @gen.coroutine
     def new_untitled(self, path='', type='', ext=''):
         with (yield self.write_lock.acquire()):
-            return (yield _new_untitled_notebook(self._config(), path, type, ext))
+            c = yield self._config()
+            return (yield _new_untitled_notebook(c, path, type, ext))
 
     @gen.coroutine
     def new(self, model, path):
         with (yield self.write_lock.acquire()):
-            return (yield _get_new_notebook(self._config(), model, path))
+            c = yield self._config()
+            return (yield _get_new_notebook(c, model, path))
 
     @gen.coroutine
     def copy(self, from_path, to_path):
         with (yield self.write_lock.acquire()):
-            return (yield _copy_notebook(self._config(), from_path, to_path))
+            c = yield self._config()
+            return (yield _copy_notebook(c, from_path, to_path))
 
     @gen.coroutine
     def create_checkpoint(self, path):
         with (yield self.write_lock.acquire()):
-            return (yield _create_new_checkpoint(self._config(), path))
+            c = yield self._config()
+            return (yield _create_new_checkpoint(c, path))
 
     @gen.coroutine
     def restore_checkpoint(self, checkpoint_id, path):
         with (yield self.write_lock.acquire()):
-            return (yield _restore_notebook_checkpoint(self._config(), checkpoint_id, path))
+            c = yield self._config()
+            return (yield _restore_notebook_checkpoint(c, checkpoint_id, path))
 
     @gen.coroutine
     def list_checkpoints(self, path):
-        return (yield _list_all_checkpoints(self._config(), path))
+        c = yield self._config()
+        return (yield _list_all_checkpoints(c, path))
 
     @gen.coroutine
     def delete_checkpoint(self, checkpoint_id, path):
         with (yield self.write_lock.acquire()):
-            return (yield _delete__notebook_checkpoint(self._config(), checkpoint_id, path))
+            c = yield self._config()
+            return (yield _delete_notebook_checkpoint(c, checkpoint_id, path))
 
+    @gen.coroutine
     def _config(self):
-        
+        authenticator = yield self.authentication.get_credentials()
+        creds = {
+            "region_name":self.region_name,
+            "bucket_name":self.bucket_name,
+            "host_name":self.host_name,
+            "cortx_authenticator":authenticator._asdict(),
+            "prefix":self.prefix,
+            "endpoint_url":self.endpoint_url
+        }
+
+        with open('.credentials',"w") as fp:
+            json.dumps(creds,fp)
+
         return Config(
             region=self.region_name,
             bucket_name=self.bucket_name,
